pub struct PostsDataFormatBuilder<'aux, 'any, DRSR> { /* private fields */ }Expand description
Temporary building structure intended to statically create packages using a fluent interface.
Implementations
sourceimpl<'aux, 'any, DRSR> PostsDataFormatBuilder<'aux, 'any, DRSR>
impl<'aux, 'any, DRSR> PostsDataFormatBuilder<'aux, 'any, DRSR>
sourcepub fn build(self) -> PostsPkg<'any, JsonRequest<PostsReq>>
pub fn build(self) -> PostsPkg<'any, JsonRequest<PostsReq>>
Final building method that creates a package with all the necessary values.